@@ -8,7 +8,7 @@ import psycopg2.extensions
 import psycopg2.extras
 import singer
 import singer.schema
-from c8connector import C8Connector, ConfigProperty, Sample
+from c8connector import C8Connector, ConfigProperty, Sample, Schema, AttributeType, Attribute
 from singer import utils, metadata, get_bookmark
 from singer.catalog import Catalog
 
@@ -472,71 +472,115 @@ class PostgresSourceConnector(C8Connector):
         """Validate given configurations against the connector.
         If invalid, throw an exception with the cause.
         """
-        config = {
-            # Required config keys
-            'host': integration['host'],
-            'user': integration['user'],
-            'password': integration['password'],
-            'port': integration['port'],
-            'dbname': integration['dbname'],
-            # Optional config keys
-            'tap_id': integration.get('tap_id'),
-            'filter_schemas': integration.get('filter_schemas'),
-            'debug_lsn': integration.get('debug_lsn') == 'true',
-            'max_run_seconds': integration.get('max_run_seconds', 43200),
-            'break_at_end_lsn': integration.get('break_at_end_lsn', True),
-            'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
-            'use_secondary': integration.get('use_secondary', False),
-        }
+        config = self.get_config(integration)
         do_discovery(config)
 
     def samples(self, integration: dict) -> list[Sample]:
         """Fetch sample data using the provided configurations."""
-        config = {
-            # Required config keys
-            'host': integration['host'],
-            'user': integration['user'],
-            'password': integration['password'],
-            'port': integration['port'],
-            'dbname': integration['dbname'],
-            # Optional config keys
-            'tap_id': integration.get('tap_id'),
-            'filter_schemas': integration.get('filter_schemas'),
-            'debug_lsn': integration.get('debug_lsn') == 'true',
-            'max_run_seconds': integration.get('max_run_seconds', 43200),
-            'break_at_end_lsn': integration.get('break_at_end_lsn', True),
-            'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
-            'use_secondary': integration.get('use_secondary', False),
-        }
+        config = self.get_config(integration)
         streams = do_discovery(config)
         results = []
         for stream in streams:
+            s_attribs = []
+            s_schema = stream['schema']
+            for k, v in s_schema['properties'].items():
+                t = v['type'][-1]
+                s_attribs.append(Attribute(k, self.get_attribute_type(t)))
+            schema = Schema(stream['stream'], s_attribs)
             results.append(Sample(
-                stream=stream,
+                schema=schema,
                 data=fetch_samples(config, stream))
             )
         return results
 
+    def schemas(self, integration: dict) -> list[Schema]:
+        """Get supported schemas using the given configurations."""
+        config = self.get_config(integration)
+        streams = do_discovery(config)
+        results = []
+        for stream in streams:
+            s_attribs = []
+            s_schema = stream['schema']
+            for k, v in s_schema['properties'].items():
+                t = v['type'][-1]
+                s_attribs.append(Attribute(k, self.get_attribute_type(t)))
+            results.append(Schema(stream['stream'], s_attribs))
+        return results
+
+    @staticmethod
+    def get_attribute_type(source_type: str) -> AttributeType:
+        if source_type == 'string':
+            return AttributeType.STRING
+        elif source_type == 'integer':
+            return AttributeType.INT
+        elif source_type == 'boolean':
+            return AttributeType.BOOLEAN
+        elif source_type == 'number':
+            return AttributeType.DOUBLE
+        else:
+            return AttributeType.OBJECT
+
     def config(self) -> list[ConfigProperty]:
         """Get configuration parameters for the connector."""
         return [
-            ConfigProperty('host', 'string', True),
-            ConfigProperty('port', 'integer', True),
-            ConfigProperty('user', 'string', True),
-            ConfigProperty('password', 'string', True),
-            ConfigProperty('dbname', 'string', True),
-            ConfigProperty('filter_schemas', 'string', False),
-            ConfigProperty('ssl', 'string', False),
-            ConfigProperty('logical_poll_total_seconds', 'integer', False),
-            ConfigProperty('break_at_end_lsn', 'boolean', False),
-            ConfigProperty('max_run_seconds', 'integer', False),
-            ConfigProperty('debug_lsn', 'string', False),
-            ConfigProperty('tap_id', 'string', False),
-            ConfigProperty('itersize', 'integer', False),
-            ConfigProperty('default_replication_method', 'string', False),
-            ConfigProperty('use_secondary', 'boolean', False),
-            ConfigProperty('secondary_host', 'string', False),
-            ConfigProperty('secondary_port', 'integer', False),
+            ConfigProperty('host', AttributeType.STRING, True, False,
+                           description='PostgreSQL host',
+                           example='51.25.44.24'),
+            ConfigProperty('port', AttributeType.INT, True, False,
+                           description='PostgreSQL port',
+                           example='5432'),
+            ConfigProperty('user', AttributeType.STRING, True, False,
+                           description='PostgreSQL user',
+                           example='postgres'),
+            ConfigProperty('password', AttributeType.STRING, True, False,
+                           description='PostgreSQL password',
+                           example='password'),
+            ConfigProperty('dbname', AttributeType.STRING, True, False,
+                           description='PostgreSQL database name',
+                           example='postgres'),
+            ConfigProperty('filter_schemas', AttributeType.STRING, False, False,
+                           description='Scan only the specified comma-separated schemas to improve the '
+                                       'performance of data extraction',
+                           example='employee,department'),
+            ConfigProperty('ssl', AttributeType.STRING, False, False,
+                           description='Using SSL via postgres sslmode=`require` option. If the server does '
+                                       'not accept SSL connections or the client certificate is not recognized '
+                                       'the connection will fail',
+                           example='false'),
+            ConfigProperty('logical_poll_total_seconds', AttributeType.INT, False, False,
+                           description='Stop running the tap when no data received from wal after '
+                                       'certain number of seconds',
+                           example='10800'),
+            ConfigProperty('break_at_end_lsn', AttributeType.BOOLEAN, False, False,
+                           description='Stop running the tap if the newly received lsn is after the max '
+                                       'lsn that was detected when the tap started.',
+                           example='false'),
+            ConfigProperty('max_run_seconds', AttributeType.INT, False, False,
+                           description='Stop running the tap after certain number of seconds',
+                           example='43200'),
+            ConfigProperty('debug_lsn', AttributeType.STRING, False, False,
+                           description='If set to "true" then add _sdc_lsn property to the singer messages '
+                                       'to debug postgres LSN position in the WAL stream.',
+                           example='false'),
+            ConfigProperty('tap_id', AttributeType.STRING, False, False,
+                           description='ID of the pipeline/tap',
+                           example=''),
+            ConfigProperty('itersize', AttributeType.INT, False, False,
+                           description='Size of PG cursor iterator when doing INCREMENTAL or FULL_TABLE.',
+                           example='20000'),
+            ConfigProperty('default_replication_method', AttributeType.STRING, False, False,
+                           description='Default replication method to use when no one is provided in the '
+                                       'catalog (Values: LOG_BASED, INCREMENTAL or FULL_TABLE).',
+                           example='LOG_BASED'),
+            ConfigProperty('use_secondary', AttributeType.BOOLEAN, False, False,
+                           description='Use a database replica for INCREMENTAL and FULL_TABLE replication.',
+                           example='false'),
+            ConfigProperty('secondary_host', AttributeType.STRING, False, False,
+                           description='PostgreSQL Replica host (required if use_secondary is True)',
+                           example='51.25.44.25'),
+            ConfigProperty('secondary_port', AttributeType.INT, False, False,
+                           description='PostgreSQL Replica port (required if use_secondary is True)',
+                           example='51.25.44.26')
         ]
 
     def capabilities(self) -> list[str]:
@@ -545,6 +589,25 @@ class PostgresSourceConnector(C8Connector):
         """
         return ['catalog', 'discover', 'state']
 
+    @staticmethod
+    def get_config(integration: dict) -> dict:
+        return {
+            # Required config keys
+            'host': integration['host'],
+            'user': integration['user'],
+            'password': integration['password'],
+            'port': integration['port'],
+            'dbname': integration['dbname'],
+            # Optional config keys
+            'tap_id': integration.get('tap_id'),
+            'filter_schemas': integration.get('filter_schemas'),
+            'debug_lsn': integration.get('debug_lsn') == 'true',
+            'max_run_seconds': integration.get('max_run_seconds', 43200),
+            'break_at_end_lsn': integration.get('break_at_end_lsn', True),
+            'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
+            'use_secondary': integration.get('use_secondary', False),
+        }
+
 
 def main():
     """
